"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.removeHeader = exports.CompileTree = void 0;
const path_1 = __importDefault(require("path"));
const __1 = require("../");
const sasjsCli_1 = require("../sasjsCli");
class CompileTree {
    constructor(treePath, tree = {}) {
        this._treePath = treePath;
        this._tree = tree;
    }
    // Returns entire tree
    get tree() {
        return this._tree;
    }
    // Returns tree leaf
    getLeaf(location) {
        return this._tree[this.getFileName(location)];
    }
    // Adds leaf
    addLeaf(leaf) {
        leaf.dependencies = (0, sasjsCli_1.getList)((0, sasjsCli_1.getDeprecatedHeader)(leaf.content, sasjsCli_1.DependencyHeader.Macro), leaf.content);
        leaf.content = (0, exports.removeHeader)(leaf.content);
        this._tree[this.getFileName(leaf.location)] = leaf;
        return leaf;
    }
    // Saves tree to sasjsbuild folder
    saveTree() {
        return __awaiter(this, void 0, void 0, function* () {
            yield (0, __1.createFile)(this._treePath, JSON.stringify(this._tree, null, 2));
        });
    }
    // If leaf exists, returns it's content.
    // Otherwise reads file, creates leaf and return content.
    getDepContent(depPath, depType) {
        return __awaiter(this, void 0, void 0, function* () {
            const leaf = this.getLeaf(depPath);
            if (leaf)
                return leaf.content;
            const content = yield (0, __1.readFile)(depPath, undefined);
            this.validateDependency(content, depPath, depType);
            return this.addLeaf({
                content,
                dependencies: [],
                location: depPath
            }).content;
        });
    }
    // Throws an error if wrong dependencies have been used
    validateDependency(content, depPath, depType) {
        if (!depType)
            return;
        const getErrorMessage = (header, dependency, depPath) => `Dependency '${header}' can not be used in artefact type '${dependency}'. Please remove it from '${depPath}'.`;
        switch (depType) {
            case sasjsCli_1.DependencyType.Macro:
                if (content.includes(sasjsCli_1.DependencyHeader.Include)) {
                    throw new Error(getErrorMessage(sasjsCli_1.DependencyHeader.Include, depType, depPath));
                }
                else if (content.includes(sasjsCli_1.DependencyHeader.Binary)) {
                    throw new Error(getErrorMessage(sasjsCli_1.DependencyHeader.Binary, depType, depPath));
                }
            default:
                break;
        }
    }
    // Returns file name based on file path
    getFileName(location) {
        return location.split(path_1.default.sep)[location.split(path_1.default.sep).length - 1];
    }
}
exports.CompileTree = CompileTree;
// Removes header from SAS file
// If string begins with a multiline comment, remove the comment
// Ignore any preceding white space or line breaks
const removeHeader = (content) => content.replace(new RegExp(`^\\s*\\/(\\*){1,2}([\\s\\S]*?)(\\*){1,2}\\/`), '');
exports.removeHeader = removeHeader;
//# sourceMappingURL=compileTree.js.map