/// <reference types="node" />
import fs from 'fs-extra';
import { LineEndings } from '../types';
export declare function fileExists(filePath: string): Promise<boolean>;
export declare function folderExists(folderPath: string): Promise<boolean>;
export declare function isFolder(inputPath: string): Promise<boolean>;
export declare function readFile(fileName: string, encoding?: BufferEncoding): Promise<string>;
export declare function readFileBinary(fileName: string): Promise<Buffer>;
export declare function listFilesInFolder(folderName: string): Promise<string[]>;
export declare function listIniFilesInFolder(folderName: string): Promise<string[]>;
/**
 * This function returns a list of all SAS files in a folder
 *
 * @param folderName a string that contains the folder path
 * @param recurse (optional) a boolean that identifies the searching of sas files in nested folders recursively
 * @param ignoredFolders (optional) a string array that contains the folders to be ignored in recursive search
 * @returns a string array containing sas files paths relatived to folderName
 */
export declare function listSasFilesInFolder(folderName: string, recurse?: boolean, ignoredFolders?: string[]): Promise<string[]>;
export declare function listSubFoldersInFolder(folderName: string): Promise<string[]>;
export declare function listFilesAndSubFoldersInFolder(folderName: string, recurse?: boolean, ignoredFolders?: string[]): Promise<string[]>;
export declare function createFolder(folderName: string): Promise<string | undefined>;
export declare function createFile(fileName: string, content: string, encoding?: BufferEncoding): Promise<void>;
export declare function deleteFile(filePath: string): Promise<void>;
export declare function deleteFolder(folderPath: string): Promise<void>;
export declare function unifyFilePath(filePath: string, separator?: string, separatorToReplace?: string): string;
export declare function getRelativePath(from: string, to: string): string;
export declare function moveFile(oldFilePath: string, newFilePath: string): Promise<void>;
export declare function copy(source: string, destination: string): Promise<void>;
export declare const pathSepEscaped: string;
export declare function base64EncodeImageFile(filePath: string): Promise<string>;
export declare function base64EncodeFile(filePath: string): Promise<string>;
export declare function getRealPath(file: string): string;
export declare function createWriteStream(filePath: string): Promise<fs.WriteStream>;
export declare const createReadStream: (filePath: string) => Promise<fs.ReadStream>;
export declare const testFileRegExp: RegExp;
export declare const isTestFile: (fileName: string) => boolean;
/**
 * Returns end of line sequence
 * @param content to get end of line sequence.
 * @returns CRLF(\r\n) or LF(\n) end of line sequence
 */
export declare const getLineEnding: (content: string) => LineEndings;
