"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getLineEnding = exports.isTestFile = exports.testFileRegExp = exports.createReadStream = exports.createWriteStream = exports.getRealPath = exports.base64EncodeFile = exports.base64EncodeImageFile = exports.pathSepEscaped = exports.copy = exports.moveFile = exports.getRelativePath = exports.unifyFilePath = exports.deleteFolder = exports.deleteFile = exports.createFile = exports.createFolder = exports.listFilesAndSubFoldersInFolder = exports.listSubFoldersInFolder = exports.listSasFilesInFolder = exports.listIniFilesInFolder = exports.listFilesInFolder = exports.readFileBinary = exports.readFile = exports.isFolder = exports.folderExists = exports.fileExists = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const utils_1 = require("../utils");
const file = __importStar(require("."));
const types_1 = require("../types");
function fileExists(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .access(filePath, fs_extra_1.default.constants.F_OK)
            .then(() => true)
            .catch(() => false);
    });
}
exports.fileExists = fileExists;
function folderExists(folderPath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .access(folderPath, fs_extra_1.default.constants.F_OK)
            .then(() => true)
            .catch(() => false);
    });
}
exports.folderExists = folderExists;
function isFolder(inputPath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .lstat(inputPath)
            .then((stat) => stat.isDirectory())
            .catch(() => false);
    });
}
exports.isFolder = isFolder;
function readFile(fileName, encoding = 'utf8') {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises.readFile(fileName, encoding);
    });
}
exports.readFile = readFile;
function readFileBinary(fileName) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises.readFile(fileName);
    });
}
exports.readFileBinary = readFileBinary;
function listFilesInFolder(folderName) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .readdir(folderName, { withFileTypes: true })
            .then((list) => list.filter((f) => !f.isDirectory()).map((f) => f.name));
    });
}
exports.listFilesInFolder = listFilesInFolder;
function listIniFilesInFolder(folderName) {
    return __awaiter(this, void 0, void 0, function* () {
        return (yield listFilesInFolder(folderName)).filter((name) => name.endsWith('.ini'));
    });
}
exports.listIniFilesInFolder = listIniFilesInFolder;
/**
 * This function returns a list of all SAS files in a folder
 *
 * @param folderName a string that contains the folder path
 * @param recurse (optional) a boolean that identifies the searching of sas files in nested folders recursively
 * @param ignoredFolders (optional) a string array that contains the folders to be ignored in recursive search
 * @returns a string array containing sas files paths relatived to folderName
 */
function listSasFilesInFolder(folderName, recurse = false, ignoredFolders = []) {
    return __awaiter(this, void 0, void 0, function* () {
        const filesAndFolders = yield listFilesAndSubFoldersInFolder(folderName, recurse, ignoredFolders);
        const sasFiles = filesAndFolders.filter((f) => f.endsWith('.sas'));
        return sasFiles;
    });
}
exports.listSasFilesInFolder = listSasFilesInFolder;
function listSubFoldersInFolder(folderName) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .readdir(folderName, { withFileTypes: true })
            .then((list) => list.filter((f) => f.isDirectory()).map((f) => f.name));
    });
}
exports.listSubFoldersInFolder = listSubFoldersInFolder;
function listFilesAndSubFoldersInFolder(folderName, recurse = true, ignoredFolders = []) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises
            .readdir(folderName, { withFileTypes: true })
            .then((list) => __awaiter(this, void 0, void 0, function* () {
            if (recurse) {
                const subFolders = list.filter((f) => f.isDirectory());
                if (subFolders.length) {
                    let subFoldersFilesAndFolders = [];
                    yield (0, utils_1.asyncForEach)(list.filter((f) => f.isDirectory()), (f) => __awaiter(this, void 0, void 0, function* () {
                        const subFolder = f.name;
                        if (!ignoredFolders.includes(subFolder)) {
                            const subPath = path_1.default.join(folderName, subFolder);
                            subFoldersFilesAndFolders = [
                                ...subFoldersFilesAndFolders,
                                ...(yield listFilesAndSubFoldersInFolder(subPath, recurse, ignoredFolders)).map((f) => path_1.default.join(subFolder, f))
                            ];
                        }
                    }));
                    return [
                        ...list.filter((f) => !f.isDirectory()).map((f) => f.name),
                        ...subFoldersFilesAndFolders
                    ];
                }
            }
            return list.map((f) => f.name);
        }));
    });
}
exports.listFilesAndSubFoldersInFolder = listFilesAndSubFoldersInFolder;
function createFolder(folderName) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises.mkdir(folderName, { recursive: true });
    });
}
exports.createFolder = createFolder;
function createFile(fileName, content, encoding) {
    return __awaiter(this, void 0, void 0, function* () {
        fileName = unifyFilePath(fileName);
        if (fileName.split(path_1.default.sep).length > 1) {
            let folderPathParts = fileName.split(path_1.default.sep);
            folderPathParts.pop();
            const folderPath = folderPathParts.join(path_1.default.sep);
            if (!(yield folderExists(folderPath))) {
                yield createFolder(folderPath);
            }
        }
        return fs_extra_1.default.promises.writeFile(fileName, content, encoding);
    });
}
exports.createFile = createFile;
function deleteFile(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.remove(filePath);
    });
}
exports.deleteFile = deleteFile;
function deleteFolder(folderPath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.rm(folderPath, {
            recursive: true,
            force: true
        });
    });
}
exports.deleteFolder = deleteFolder;
function unifyFilePath(filePath, separator = path_1.default.sep, separatorToReplace = '/') {
    const separators = { unix: '/', win: '\\' };
    let osSeparator = Object.keys(separators).find((key) => separators[key] === separator);
    if (osSeparator) {
        const notValidSeparator = separators[Object.keys(separators).find((key) => key !== osSeparator)];
        osSeparator = separators[osSeparator];
        return filePath.split(notValidSeparator).join(osSeparator);
    }
    return filePath.split(separatorToReplace).join(separator);
}
exports.unifyFilePath = unifyFilePath;
function getRelativePath(from, to) {
    const fromFolders = from.split(path_1.default.sep);
    const toFolders = to.split(path_1.default.sep);
    let commonPathParts = [];
    let relativePathParts = [];
    fromFolders.forEach((fromFolder, i) => {
        if (toFolders[i] !== undefined && fromFolders[i] === toFolders[i]) {
            commonPathParts.push(fromFolder);
        }
        else {
            if (fromFolder)
                relativePathParts.push(fromFolder);
        }
    });
    const commonPath = commonPathParts.join(path_1.default.sep);
    const leadingPathSepRegExp = new RegExp(`^${path_1.default.sep.replace(/\\/g, '\\\\')}`);
    const trailingPathSepRegExp = new RegExp(`${path_1.default.sep.replace(/\\/g, '\\\\')}$`);
    const relativePath = (relativePathParts.length
        ? `..${path_1.default.sep}`.repeat(relativePathParts.length)
        : `.${path_1.default.sep}`) +
        to
            .replace(commonPath, '')
            .replace(leadingPathSepRegExp, '')
            .replace(trailingPathSepRegExp, '');
    return relativePath;
}
exports.getRelativePath = getRelativePath;
function moveFile(oldFilePath, newFilePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises.rename(oldFilePath, newFilePath);
    });
}
exports.moveFile = moveFile;
function copy(source, destination) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.copy(source, destination);
    });
}
exports.copy = copy;
exports.pathSepEscaped = path_1.default.sep.replace(/\\/g, '\\\\');
function base64EncodeImageFile(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return readFileBinary(filePath).then((data) => {
            let extname = path_1.default.extname(filePath).substr(1) || 'png';
            if (extname === 'svg') {
                extname = 'svg+xml';
            }
            return 'data:image/' + extname + ';base64,' + data.toString('base64');
        });
    });
}
exports.base64EncodeImageFile = base64EncodeImageFile;
function base64EncodeFile(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        return fs_extra_1.default.promises.readFile(filePath, { encoding: 'base64' });
    });
}
exports.base64EncodeFile = base64EncodeFile;
function getRealPath(file) {
    return fs_extra_1.default.realpathSync(file);
}
exports.getRealPath = getRealPath;
function createWriteStream(filePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const isFilePresent = yield file.fileExists(filePath);
        if (isFilePresent) {
            return fs_extra_1.default.createWriteStream(filePath, { flags: 'a' });
        }
        yield file.createFile(filePath, '');
        return fs_extra_1.default.createWriteStream(filePath, { flags: 'a' });
    });
}
exports.createWriteStream = createWriteStream;
const createReadStream = (filePath) => __awaiter(void 0, void 0, void 0, function* () { return fs_extra_1.default.createReadStream(filePath); });
exports.createReadStream = createReadStream;
exports.testFileRegExp = /\.test\.(\d+\.)?sas$/i;
const isTestFile = (fileName) => exports.testFileRegExp.test(fileName);
exports.isTestFile = isTestFile;
/**
 * Returns end of line sequence
 * @param content to get end of line sequence.
 * @returns CRLF(\r\n) or LF(\n) end of line sequence
 */
const getLineEnding = (content) => new RegExp(types_1.LineEndings.CRLF).test(content) ? types_1.LineEndings.CRLF : types_1.LineEndings.LF;
exports.getLineEnding = getLineEnding;
//# sourceMappingURL=file.js.map