"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateCompileProgram = void 0;
const path_1 = __importDefault(require("path"));
const file_1 = require("../file");
const utils_1 = require("../utils");
const helper_1 = require("./internal/helper");
const generateCompileProgram = (folderPath) => __awaiter(void 0, void 0, void 0, function* () {
    const compiledMacrosCode = yield (0, helper_1.getCompiledMacrosCode)([
        'mf_mkdir.sas',
        'mp_dirlist.sas',
        'mf_existds.sas',
        'mf_getvarlist.sas',
        'mf_wordsinstr1butnotstr2.sas',
        'mp_dropmembers.sas'
    ]);
    const initialProgramContent = (0, helper_1.getInitialCode)();
    const folderCreationCode = yield fileAndDirectoryCreationCode(folderPath);
    return compiledMacrosCode + initialProgramContent + folderCreationCode;
});
exports.generateCompileProgram = generateCompileProgram;
const fileAndDirectoryCreationCode = (resourcePath, pathRelativeTo = resourcePath, resultCode = '') => __awaiter(void 0, void 0, void 0, function* () {
    if (!(yield (0, file_1.isFolder)(resourcePath))) {
        resultCode += yield (0, helper_1.generateCodeForFileCreation)(resourcePath, pathRelativeTo);
        return resultCode;
    }
    const files = yield (0, file_1.listFilesInFolder)(resourcePath);
    for (const file of files) {
        resultCode = yield fileAndDirectoryCreationCode(path_1.default.join(resourcePath, file), pathRelativeTo, resultCode);
    }
    const subFolders = yield (0, file_1.listSubFoldersInFolder)(resourcePath);
    for (const folder of subFolders) {
        const folderPath = path_1.default.join(resourcePath, folder);
        resultCode = `${resultCode}
%mf_mkdir(&fsTarget${(0, utils_1.generatePathForSas)(folderPath.replace(pathRelativeTo, ''))})
`;
        resultCode = yield fileAndDirectoryCreationCode(folderPath, pathRelativeTo, resultCode);
    }
    return resultCode;
});
//# sourceMappingURL=generateCompileProgram.js.map