"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getCompiledMacrosCode = exports.getInitialCode = exports.chunkFileContent = exports.generateCodeForFileCreation = void 0;
const path_1 = __importDefault(require("path"));
const utils_1 = require("../../utils");
const file_1 = require("../../file");
const generateCodeForFileCreation = (filePath, pathRelativeTo) => __awaiter(void 0, void 0, void 0, function* () {
    const base64EncodedFileContent = yield (0, file_1.base64EncodeFile)(filePath);
    const chunkedFileContent = (0, exports.chunkFileContent)(base64EncodedFileContent);
    return `
filename _in64 temp lrecl=99999999;
data _null_;
file _in64;
${chunkedFileContent}
run;

filename _out64 "&fsTarget${(0, utils_1.generatePathForSas)(filePath.replace(pathRelativeTo, ''))}";

/* convert from base64 */
data _null_;
length filein 8 fileout 8;
filein = fopen("_in64",'I',4,'B');
fileout = fopen("_out64",'O',3,'B');
char= '20'x;
do while(fread(filein)=0);
  length raw $4 ;
  do i=1 to 4;
    rc=fget(filein,char,1);
    substr(raw,i,1)=char;
  end;
  rc = fput(fileout, input(raw,$base64X4.));
  rc =fwrite(fileout);
end;
rc = fclose(filein);
rc = fclose(fileout);
run;

filename _in64 clear;
filename _out64 clear;
`;
});
exports.generateCodeForFileCreation = generateCodeForFileCreation;
const chunkFileContent = (fileContent) => {
    const chunkedLines = (0, utils_1.chunk)(fileContent);
    if (chunkedLines.length === 1) {
        return ` put '${chunkedLines[0].split("'").join("''")}';\n`;
    }
    let combinedLines = '';
    chunkedLines.forEach((chunkedLine, index) => {
        const text = ` put '${chunkedLine.split("'").join("''")}'${index !== chunkedLines.length - 1 ? '@;\n' : ';\n'}`;
        combinedLines += text;
    });
    return combinedLines;
};
exports.chunkFileContent = chunkFileContent;
const getInitialCode = () => `%global fsTarget;
%let compiled_fsTarget=%sysfunc(pathname(work));
%let fsTarget=%sysfunc(coalescec(&fsTarget,&compiled_fsTarget));
options nobomfile;

%mf_mkdir(&fsTarget)
`;
exports.getInitialCode = getInitialCode;
const getCompiledMacrosCode = (macros) => __awaiter(void 0, void 0, void 0, function* () {
    let compiledCode = '';
    for (const macro of macros) {
        const macroPath = path_1.default.join((0, utils_1.getMacrosPath)(), macro);
        const macroContent = yield (0, file_1.readFile)(macroPath);
        compiledCode += macroContent + '\n';
    }
    return compiledCode;
});
exports.getCompiledMacrosCode = getCompiledMacrosCode;
//# sourceMappingURL=helper.js.map