"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findResourcesNotPresentLocally = exports.generateProgramToSyncHashDiff = exports.generateProgramToGetRemoteHash = void 0;
const path_1 = __importDefault(require("path"));
const helper_1 = require("./internal/helper");
const utils_1 = require("../utils");
// we need to inject this line to generated sas program
// ls means line size and ps means page size
// bigger page = less chance of hitting the page number
const OPTIONS = 'options ls=max ps=max;';
const generateProgramToGetRemoteHash = (remotePath) => __awaiter(void 0, void 0, void 0, function* () {
    const compiledMacrosCode = yield (0, helper_1.getCompiledMacrosCode)([
        'mp_hashdirectory.sas',
        'mp_jsonout.sas',
        'mp_dirlist.sas',
        'mf_existds.sas',
        'mf_getvarlist.sas',
        'mf_wordsinstr1butnotstr2.sas',
        'mp_dropmembers.sas',
        'mf_isblank.sas'
    ]);
    const codeForHashCreation = getCodeForHashCreation();
    const code = OPTIONS + compiledMacrosCode + codeForHashCreation;
    return setTargetAtStart(code, remotePath);
});
exports.generateProgramToGetRemoteHash = generateProgramToGetRemoteHash;
const generateProgramToSyncHashDiff = (hashedFolder, remotePath) => __awaiter(void 0, void 0, void 0, function* () {
    const compiledMacrosCode = yield (0, helper_1.getCompiledMacrosCode)([
        'mp_hashdirectory.sas',
        'mp_jsonout.sas',
        'mf_mkdir.sas',
        'mp_dirlist.sas',
        'mf_existds.sas',
        'mf_getvarlist.sas',
        'mf_wordsinstr1butnotstr2.sas',
        'mp_dropmembers.sas',
        'mf_isblank.sas'
    ]);
    const initialProgramContent = (0, helper_1.getInitialCode)();
    const pathRelativeTo = hashedFolder.absolutePath.endsWith(path_1.default.sep)
        ? hashedFolder.absolutePath.slice(0, -1)
        : hashedFolder.absolutePath;
    const folderCreationCode = yield generateCodeForFolderCreation(hashedFolder, pathRelativeTo);
    const codeForHashCreation = getCodeForHashCreation();
    const code = OPTIONS +
        compiledMacrosCode +
        initialProgramContent +
        folderCreationCode +
        codeForHashCreation;
    return setTargetAtStart(code, remotePath);
});
exports.generateProgramToSyncHashDiff = generateProgramToSyncHashDiff;
const findResourcesNotPresentLocally = (localHash, remoteHashMap) => {
    const localHashedArray = convertHashFolderTreeToArray(localHash);
    const remoteHashedArray = Object.keys(remoteHashMap);
    return remoteHashedArray.filter((item) => !localHashedArray.includes(item));
};
exports.findResourcesNotPresentLocally = findResourcesNotPresentLocally;
const generateCodeForFolderCreation = (hashedFolder, pathRelativeTo, resultCode = '') => __awaiter(void 0, void 0, void 0, function* () {
    for (const member of hashedFolder.members) {
        if (member.isFile) {
            resultCode += yield (0, helper_1.generateCodeForFileCreation)(member.absolutePath, pathRelativeTo);
        }
        else {
            resultCode += `%mf_mkdir(&fsTarget${(0, utils_1.generatePathForSas)(member.absolutePath.replace(pathRelativeTo, ''))})\n`;
            resultCode = yield generateCodeForFolderCreation(member, pathRelativeTo, resultCode);
        }
    }
    return resultCode;
});
const getCodeForHashCreation = () => {
    return `/* Get Hashes */
%mp_hashdirectory(&fsTarget,maxDepth=MAX,outds=work.hashes)

/* Prepare Response JSON */
filename tmp temp;
%mp_jsonout(OPEN,jref=tmp)
%mp_jsonout(OBJ,hashes,fmt=N,jref=tmp)
%mp_jsonout(CLOSE,jref=tmp)

/* Print to Log */
data _null_;
  retain eof;
  infile tmp end=eof lrecl=10000;
  if _n_=1 then putlog '>>weboutBEGIN<<';
  input;
  putlog _infile_;
  if eof then putlog '>>weboutEND<<';
run;
`;
};
const setTargetAtStart = (code, targetPath) => {
    return `%let fsTarget=${(0, utils_1.generatePathForSas)(targetPath)};\n${code}`;
};
/**
 * convert hash folder tree to an array of relative paths,
 * the returned array will be used to check the resources that are present on remote but not local
 */
const convertHashFolderTreeToArray = (hashedFolder, array = []) => {
    if (hashedFolder.isFile)
        return [...array, hashedFolder.relativePath];
    for (const member of hashedFolder.members) {
        array = convertHashFolderTreeToArray(member, array);
    }
    array.push(hashedFolder.relativePath);
    return array;
};
//# sourceMappingURL=sync.js.map