"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readAndValidateInput = exports.getUrl = exports.getChoice = exports.getConfirmation = exports.getString = exports.getNumber = exports.onCancel = void 0;
const prompts_1 = __importDefault(require("prompts"));
const validators_1 = require("./validators");
const defaultErrorMessage = 'Invalid input.';
const isValidInputType = (type) => type === 'number' ||
    type === 'text' ||
    type === 'select' ||
    type === 'confirm' ||
    type === 'url';
const onCancel = () => {
    console.error('Input cancelled. Exiting...');
    process.exit(1);
};
exports.onCancel = onCancel;
const getNumber = (message, validator, defaultValue) => __awaiter(void 0, void 0, void 0, function* () {
    const { number } = yield (0, exports.readAndValidateInput)('number', 'number', message, validator, defaultValue);
    if (!Number.isNaN(number) &&
        !(typeof number === 'string') &&
        number !== null &&
        number !== undefined) {
        return number;
    }
    throw new Error(defaultErrorMessage);
});
exports.getNumber = getNumber;
const getString = (message, validator, defaultValue = '') => __awaiter(void 0, void 0, void 0, function* () {
    const { text } = yield (0, exports.readAndValidateInput)('text', 'text', message, validator, defaultValue);
    if (text !== null && text !== undefined) {
        return text;
    }
    throw new Error(defaultErrorMessage);
});
exports.getString = getString;
const getConfirmation = (message, defaultValue) => __awaiter(void 0, void 0, void 0, function* () {
    const { confirm } = yield (0, exports.readAndValidateInput)('confirm', 'confirm', message, validators_1.confirmationValidator, defaultValue);
    if (confirm === true || confirm === false) {
        return confirm;
    }
    throw new Error(defaultErrorMessage);
});
exports.getConfirmation = getConfirmation;
const getChoice = (message, errorMessage, choices = []) => __awaiter(void 0, void 0, void 0, function* () {
    const { choice } = yield (0, exports.readAndValidateInput)('select', 'choice', message, (value) => (0, validators_1.choiceValidator)(value, choices.length, errorMessage), 0, choices);
    if (!Number.isNaN(choice) &&
        !(typeof choice === 'string') &&
        choice !== null &&
        choice !== undefined) {
        return choice;
    }
    throw new Error(errorMessage);
});
exports.getChoice = getChoice;
const getUrl = (message, errorMessage, defaultValue = '') => __awaiter(void 0, void 0, void 0, function* () {
    const { url } = yield (0, exports.readAndValidateInput)('text', 'url', message, (value) => (0, validators_1.urlValidator)(value, errorMessage), defaultValue);
    if (!!url || url === '') {
        return url;
    }
    throw new Error(errorMessage);
});
exports.getUrl = getUrl;
const readAndValidateInput = (type, fieldName, message, validator, defaultValue = '', choices = []) => __awaiter(void 0, void 0, void 0, function* () {
    if (!isValidInputType(type)) {
        throw new Error('Invalid input type. Valid input types are `text`, `number`, `url`, `confirm` and `select`');
    }
    if (type !== 'select' && choices.length) {
        throw new Error('Choices are only supported with the `select` input type.');
    }
    if (type === 'select' && !choices.length) {
        throw new Error('A set of choices is required to be supplied with the `select` input type.');
    }
    if (type === 'select') {
        return yield (0, prompts_1.default)({
            type,
            name: fieldName,
            initial: defaultValue,
            message,
            choices,
            validate: validator
        }, {
            onCancel: exports.onCancel
        });
    }
    return yield (0, prompts_1.default)({
        type,
        name: fieldName,
        initial: defaultValue,
        message,
        validate: validator
    }, {
        onCancel: exports.onCancel
    });
});
exports.readAndValidateInput = readAndValidateInput;
//# sourceMappingURL=readAndValidateInput.js.map