"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const consola_1 = __importDefault(require("consola"));
const isLowerThanOrEqualTo_1 = require("./isLowerThanOrEqualTo");
const isNullOrUndefined_1 = require("./isNullOrUndefined");
const logLevel_1 = require("./logLevel");
const formatter_1 = require("../formatter");
const cli_table_1 = __importDefault(require("cli-table"));
const chalk_1 = __importDefault(require("chalk"));
class Logger {
    constructor(logLevel) {
        this._logLevel = logLevel_1.LogLevel.Error;
        this.trace = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Trace)) {
                consola_1.default.debug(message, ...this.filterArgs(args));
            }
        };
        this.debug = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Debug)) {
                consola_1.default.debug(message, ...this.filterArgs(args));
            }
        };
        this.info = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Info)) {
                consola_1.default.info(message, ...this.filterArgs(args));
            }
        };
        this.success = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Info)) {
                consola_1.default.success(message, ...this.filterArgs(args));
            }
        };
        this.warn = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Warn)) {
                consola_1.default.warn(message, ...args);
            }
        };
        this.error = (message, ...args) => {
            if ((0, isLowerThanOrEqualTo_1.isLowerThanOrEqualTo)(this._logLevel, logLevel_1.LogLevel.Error)) {
                consola_1.default.error(message, ...this.filterArgs(args));
            }
        };
        this.log = (message, ...args) => {
            consola_1.default.log(message, ...this.filterArgs(args));
        };
        this.table = (data, options, disableStyling) => {
            var _a;
            const defaultOptions = {
                chars: {
                    top: '═',
                    'top-mid': '╤',
                    'top-left': '╔',
                    'top-right': '╗',
                    bottom: '═',
                    'bottom-mid': '╧',
                    'bottom-left': '╚',
                    'bottom-right': '╝',
                    left: '║',
                    'left-mid': '╟',
                    mid: '─',
                    'mid-mid': '┼',
                    right: '║',
                    'right-mid': '╢',
                    middle: '│'
                },
                head: []
            };
            let table;
            if (options && Object.keys(options).length) {
                table = new cli_table_1.default({
                    chars: options.chars || defaultOptions.chars,
                    head: ((_a = options.head) === null || _a === void 0 ? void 0 : _a.map((header) => chalk_1.default.white.bold(header))) ||
                        defaultOptions.head
                });
            }
            else {
                table = new cli_table_1.default({
                    chars: defaultOptions.chars
                });
            }
            data.forEach((item) => table.push(item));
            this.log((disableStyling
                ? (0, formatter_1.sanitizeSpecialChars)(table.toString())
                : table.toString()) + '\n');
        };
        if (!(0, isNullOrUndefined_1.isNullOrUndefined)(logLevel) && logLevel in logLevel_1.LogLevel) {
            this._logLevel = logLevel;
        }
    }
    get logLevel() {
        return this._logLevel;
    }
    set logLevel(value) {
        this._logLevel = value;
    }
    filterArgs(args) {
        return args.filter((arg) => (arg ? arg : false));
    }
}
exports.Logger = Logger;
//# sourceMappingURL=logger.js.map