"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDeprecatedHeader = exports.getDependencies = exports.getDepInfo = exports.DependencyHeader = exports.DependencyType = void 0;
const utils_1 = require("../utils");
const _1 = require("./");
const utils_2 = require("../utils");
const find_1 = __importDefault(require("find"));
const file_1 = require("../file");
const formatter_1 = require("../formatter");
// REFACTOR: move logic supporting SAS Macros dependencies to this file
var DependencyType;
(function (DependencyType) {
    DependencyType["Macro"] = "Macro";
    DependencyType["Include"] = "Include";
    DependencyType["Binary"] = "Binary";
})(DependencyType = exports.DependencyType || (exports.DependencyType = {}));
var DependencyHeader;
(function (DependencyHeader) {
    DependencyHeader["Macro"] = "<h4> SAS Macros </h4>";
    DependencyHeader["Binary"] = "<h4> Binary Files </h4>";
    DependencyHeader["Include"] = "<h4> SAS Includes </h4>";
    DependencyHeader["DataInput"] = "<h4> Data Inputs </h4>";
    DependencyHeader["DataOutput"] = "<h4> Data Outputs </h4>";
    DependencyHeader["DeprecatedMacro"] = "<h4> Dependencies </h4>";
    DependencyHeader["DeprecatedInclude"] = "<h4> SAS Programs </h4>";
})(DependencyHeader = exports.DependencyHeader || (exports.DependencyHeader = {}));
const getDepInfo = (depType, fileContent) => {
    const header = depType === DependencyType.Include
        ? fileContent.includes(DependencyHeader.Include)
            ? DependencyHeader.Include
            : DependencyHeader.DeprecatedInclude
        : DependencyHeader[depType];
    const depInfo = {
        name: getHeaderName(header),
        header: depType === DependencyType.Include
            ? fileContent.includes(DependencyHeader.Include)
                ? DependencyHeader.Include
                : DependencyHeader.DeprecatedInclude
            : DependencyHeader[depType],
        config: `${(depType === DependencyType.Include
            ? 'Program'
            : depType).toLowerCase()}Folders`,
        type: depType
    };
    return depInfo;
};
exports.getDepInfo = getDepInfo;
const getDependencies = (fileName, fileContent, folders, depType, compileTree) => __awaiter(void 0, void 0, void 0, function* () {
    folders = (0, utils_1.uniqArray)(folders);
    const depInfo = (0, exports.getDepInfo)(depType, fileContent);
    const deps = deconstructDependency((0, _1.getList)(depInfo.header, fileContent), depInfo);
    const uniqDeps = [];
    deps.forEach((dep) => uniqDeps.find((d) => dep.fileName === d.fileName) || uniqDeps.push(dep));
    if (uniqDeps.length) {
        const foundDeps = [];
        const foundDepsNames = [];
        yield (0, utils_2.asyncForEach)(folders, (folder) => __awaiter(void 0, void 0, void 0, function* () {
            yield (0, utils_2.asyncForEach)(uniqDeps, (dep) => __awaiter(void 0, void 0, void 0, function* () {
                const filePaths = find_1.default.fileSync(dep.fileName, folder);
                if (filePaths.length) {
                    let encodedFileContent = '';
                    if (compileTree &&
                        Object.keys(compileTree).length &&
                        depType !== DependencyType.Binary) {
                        encodedFileContent = yield compileTree.getDepContent(filePaths[0], depType);
                    }
                    else {
                        encodedFileContent = yield (0, file_1.readFile)(filePaths[0], depType === DependencyType.Binary ? 'base64' : undefined);
                    }
                    const depContent = compileDep(depType, encodedFileContent, dep.fileRef);
                    foundDeps.push(depContent);
                    foundDepsNames.push(dep.fileName);
                }
            }));
        }));
        const notFoundDeps = deps
            .filter((dep) => !foundDepsNames.includes(dep.fileName))
            .map((dep, i) => `${i + 1}. '${dep.fileName}' with fileRef '${dep.fileRef}'`)
            .join('\n');
        if (notFoundDeps.length) {
            let depFolder = depInfo.config.replace(/([A-Z]+)/g, ' $1');
            depFolder = (0, formatter_1.capitalizeFirstChar)(depFolder);
            throw new Error(`Unable to load dependencies for: ${fileName || ''}\n` +
                `The following files were listed under ${depInfo.name} but could not be found:\n` +
                `${notFoundDeps}\n` +
                `Please check that they exist in the folder(s) listed in the \`${depInfo.config}\` array in your sasjsconfig.json file.\n` +
                `${depFolder}:\n` +
                folders.map((folder) => `- ${folder}`).join('\n'));
        }
        return foundDeps.join('\n');
    }
    return '';
});
exports.getDependencies = getDependencies;
const getDeprecatedHeader = (fileContent, header) => fileContent.includes(header)
    ? header
    : header === DependencyHeader.Macro
        ? DependencyHeader.DeprecatedMacro
        : DependencyHeader.DeprecatedInclude;
exports.getDeprecatedHeader = getDeprecatedHeader;
const deconstructDependency = (deps, depInfo) => deps.map((dep) => {
    const [fileName, fileRef] = dep.split(' ').filter((f) => !!f);
    if (!fileName) {
        throw new Error(`${depInfo.name} entry is empty. Please specify ${depInfo.name} dependencies in the format: @li <filename> <fileref>`);
    }
    if (!fileRef && depInfo.type !== DependencyType.Macro) {
        throw new Error(`${depInfo.name} ${fileName} is missing fileref. Please specify ${depInfo.name} dependencies in the format: @li <filename> <fileref>`);
    }
    if (depInfo.type !== DependencyType.Macro)
        (0, _1.validateFileRef)(fileRef);
    return { fileName, fileRef };
});
const compileDep = (depType, fileContent, fileRef) => {
    let output = '';
    if (depType === DependencyType.Binary) {
        output = [
            `filename _sjstmp "%sysfunc(pathname(work))/base64_${fileRef}" recfm=n;`,
            `data _null_;`,
            `file _sjstmp;\n`
        ].join(`\n`);
        const sourceLines = fileContent
            .replace(/\r\n/g, '\n')
            .split('\n')
            .filter((l) => !!l);
        sourceLines.forEach((line) => {
            const chunkedLines = (0, utils_2.chunk)(line);
            if (chunkedLines.length === 1) {
                output += `put '${chunkedLines[0].split("'").join("''")}';\n`;
            }
            else {
                let combinedLines = '';
                chunkedLines.forEach((chunkedLine, index) => {
                    let text = `put '${chunkedLine.split("'").join("''")}'`;
                    if (index !== chunkedLines.length - 1) {
                        text += '@;\n';
                    }
                    else {
                        text += ';\n';
                    }
                    combinedLines += text;
                });
                output += combinedLines;
            }
        });
        output += `run;\n`;
        const sasCodeToDecodeBase64 = [
            `filename ${fileRef} "%sysfunc(pathname(work))/sasjs_${fileRef}";`,
            `data _null_;`,
            `length filein 8 fileout 8;`,
            `filein = fopen("_sjstmp",'I',4,'B');`,
            `fileout = fopen("${fileRef}",'O',3,'B');`,
            `char= '20'x;`,
            `do while(fread(filein)=0);`,
            `length raw $4;`,
            `do i=1 to 4;`,
            `rc=fget(filein,char,1);`,
            `substr(raw,i,1)=char;`,
            `end;`,
            `rc = fput(fileout,input(raw,$base64X4.));`,
            `rc = fwrite(fileout);`,
            `end;`,
            `rc = fclose(filein);`,
            `rc = fclose(fileout);`,
            `run;`,
            `filename _sjstmp clear;`
        ];
        output += sasCodeToDecodeBase64.join(`\n`);
    }
    else if (depType === DependencyType.Include) {
        output = `filename ${fileRef} temp;\ndata _null_;\nfile ${fileRef} lrecl=32767;\n`;
        const sourceLines = fileContent
            .replace(/\r\n/g, '\n')
            .split('\n')
            .filter((l) => !!l);
        sourceLines.forEach((line) => {
            const chunkedLines = (0, utils_2.chunk)(line);
            if (chunkedLines.length === 1) {
                output += `put '${chunkedLines[0].split("'").join("''")}';\n`;
            }
            else {
                let combinedLines = '';
                chunkedLines.forEach((chunkedLine, index) => {
                    let text = `put '${chunkedLine.split("'").join("''")}'`;
                    if (index !== chunkedLines.length - 1) {
                        text += '@;\n';
                    }
                    else {
                        text += ';\n';
                    }
                    combinedLines += text;
                });
                output += combinedLines;
            }
        });
        output += 'run;';
    }
    return output;
};
const getHeaderName = (header) => header.replace(/^<h4>\s/, '').replace(/\s<\/h4>$/, '');
//# sourceMappingURL=getDependencies.js.map