"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDependencyPaths = void 0;
const find_1 = __importDefault(require("find"));
const file_1 = require("../file");
const utils_1 = require("../utils");
const _1 = require("./");
function getDependencyPaths(fileContent, macroFolders, macroCorePath, compileTree, leaf) {
    return __awaiter(this, void 0, void 0, function* () {
        let dependencyPaths = [];
        const foundDependencies = [];
        const sourcePaths = [...macroFolders, macroCorePath];
        const dependenciesHeader = (0, _1.getDeprecatedHeader)(fileContent, _1.DependencyHeader.Macro);
        const dependencies = (leaf === null || leaf === void 0 ? void 0 : leaf.dependencies) ||
            (0, _1.getList)(dependenciesHeader, fileContent).filter((d) => d.endsWith('.sas'));
        // Search dependencies recursively starting from macroFolders and ending in macroCorePath
        yield (0, utils_1.asyncForEach)(sourcePaths, (sourcePath) => __awaiter(this, void 0, void 0, function* () {
            if (yield (0, file_1.folderExists)(sourcePath)) {
                yield (0, utils_1.asyncForEach)(dependencies, (dep) => __awaiter(this, void 0, void 0, function* () {
                    const filePaths = find_1.default.fileSync(dep, sourcePath);
                    if (filePaths.length) {
                        let fileContent = '';
                        let leaf = undefined;
                        if (compileTree && Object.keys(compileTree).length) {
                            fileContent = yield compileTree.getDepContent(filePaths[0], _1.DependencyType.Macro);
                            leaf = compileTree.getLeaf(filePaths[0]);
                        }
                        else {
                            fileContent = yield (0, file_1.readFile)(filePaths[0]);
                        }
                        foundDependencies.push(dep);
                        dependencyPaths.push(...(yield getDependencyPaths(fileContent, macroFolders, macroCorePath, compileTree, leaf)));
                    }
                    dependencyPaths.push(...filePaths);
                }));
            }
            else if (macroFolders.includes(sourcePath)) {
                throw `Error listing dependency paths: Source path ${sourcePath} does not exist.`;
            }
        }));
        const notFoundDependencies = (0, utils_1.diff)(dependencies, foundDependencies);
        if (notFoundDependencies.length) {
            throw 'Unable to locate dependencies: ' + notFoundDependencies.join(', ');
        }
        dependencyPaths = (0, _1.prioritiseDependencyOverrides)(dependencies, dependencyPaths, macroFolders);
        return [...new Set(dependencyPaths)];
    });
}
exports.getDependencyPaths = getDependencyPaths;
//# sourceMappingURL=getDependencyPaths.js.map