"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.mockGetProgram = exports.getProgram = exports.getInitTerm = exports.ProgramType = void 0;
const file_1 = require("../file");
const types_1 = require("../types");
const utils_1 = require("../utils");
const formatter_1 = require("../formatter");
var ProgramType;
(function (ProgramType) {
    ProgramType["Init"] = "init";
    ProgramType["Term"] = "term";
})(ProgramType = exports.ProgramType || (exports.ProgramType = {}));
const getInitTerm = ({ configuration, target, fileType, buildSourceFolder, compileTree }) => __awaiter(void 0, void 0, void 0, function* () {
    const { content: init, filePath: initPath, compileTreeLeaf: initLeaf } = yield (0, exports.getProgram)({
        target,
        configuration,
        buildSourceFolder,
        fileType,
        compileTree
    }, ProgramType.Init, compileTree);
    const { content: term, filePath: termPath, compileTreeLeaf: termLeaf } = yield (0, exports.getProgram)({
        target,
        configuration,
        buildSourceFolder,
        fileType,
        compileTree
    }, ProgramType.Term, compileTree);
    const startUpVars = getVars(fileType, target, configuration);
    return {
        init,
        initPath,
        term,
        termPath,
        startUpVars,
        initLeaf,
        termLeaf
    };
});
exports.getInitTerm = getInitTerm;
const getVars = (varType, target, configuration) => {
    const getInternalVars = (config) => {
        var _a, _b, _c;
        return varType === types_1.SASJsFileType.service
            ? (_a = config === null || config === void 0 ? void 0 : config.serviceConfig) === null || _a === void 0 ? void 0 : _a.macroVars
            : varType === types_1.SASJsFileType.job
                ? (_b = config === null || config === void 0 ? void 0 : config.jobConfig) === null || _b === void 0 ? void 0 : _b.macroVars
                : varType === types_1.SASJsFileType.test
                    ? (_c = config === null || config === void 0 ? void 0 : config.testConfig) === null || _c === void 0 ? void 0 : _c.macroVars
                    : {};
    };
    const targetVars = getInternalVars(target);
    const commonServiceVars = getInternalVars(configuration);
    return convertVarsToSasFormat(Object.assign(Object.assign({}, commonServiceVars), targetVars));
};
const convertVarsToSasFormat = (vars) => {
    const entries = Object.entries(vars);
    let varsContent = '\n';
    for (const [name, value] of entries) {
        const chunks = (0, utils_1.chunk)(value);
        const chunkedString = chunks.join('%trim(\n)');
        varsContent += `%let ${name}=${chunkedString};\n`;
    }
    return varsContent;
};
const getProgram = ({ target, configuration, buildSourceFolder, fileType }, programType, compileTree) => __awaiter(void 0, void 0, void 0, function* () {
    let programContent = '', filePath = '';
    let program = undefined;
    let targetConfig = undefined;
    let rootConfig = undefined;
    switch (fileType) {
        case types_1.SASJsFileType.service:
            targetConfig = target === null || target === void 0 ? void 0 : target.serviceConfig;
            rootConfig = configuration === null || configuration === void 0 ? void 0 : configuration.serviceConfig;
            break;
        case types_1.SASJsFileType.job:
            targetConfig = target === null || target === void 0 ? void 0 : target.jobConfig;
            rootConfig = configuration === null || configuration === void 0 ? void 0 : configuration.jobConfig;
            break;
        case types_1.SASJsFileType.test:
            targetConfig = target === null || target === void 0 ? void 0 : target.testConfig;
            rootConfig = configuration === null || configuration === void 0 ? void 0 : configuration.testConfig;
            break;
    }
    program =
        (targetConfig &&
            targetConfig[`${programType}Program`]) ||
            (rootConfig &&
                rootConfig[`${programType}Program`]);
    if (program) {
        filePath = (0, file_1.getAbsolutePath)(program, buildSourceFolder);
        programContent = yield compileTree.getDepContent(filePath);
    }
    const content = programContent
        ? `\n* ${fileType}${(0, formatter_1.capitalizeFirstChar)(programType)} start;\n${programContent}\n* ${fileType}${(0, formatter_1.capitalizeFirstChar)(programType)} end;`
        : '';
    const compileTreeLeaf = compileTree.getLeaf(filePath);
    return {
        content,
        filePath,
        compileTreeLeaf
    };
});
exports.getProgram = getProgram;
const mockGetProgram = (module, fakeInit, fakeTerm) => {
    jest.spyOn(module, 'getProgram').mockImplementation((params, programType) => programType === ProgramType.Init
        ? Promise.resolve({
            content: `\n* ${params.fileType}Init start;\n${fakeInit}\n* ${params.fileType}Init end;`,
            filePath: ''
        })
        : Promise.resolve({
            content: `\n* ${params.fileType}Term start;\n${fakeTerm}\n* ${params.fileType}Term end;`,
            filePath: ''
        }));
};
exports.mockGetProgram = mockGetProgram;
//# sourceMappingURL=getInitTerm.js.map