"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPreCode = exports.preCodeViya = exports.preCodeEnd = exports.callWeboutMacro = void 0;
const types_1 = require("../types");
const file_1 = require("../file");
const path_1 = __importDefault(require("path"));
const callWeboutMacro = (macro) => `%macro webout(action,ds,dslabel=,fmt=,missing=NULL,showmeta=NO,maxobs=MAX);
  %${macro}(&action,ds=&ds,dslabel=&dslabel,fmt=&fmt
    ,missing=&missing
    ,showmeta=&showmeta
    ,maxobs=&maxobs
  ) %mend;
`;
exports.callWeboutMacro = callWeboutMacro;
exports.preCodeEnd = `/* provide additional debug info */
%global _program;
%put &=syscc;
%put user=%mf_getuser();
%put pgm=&_program;
%put timestamp=%sysfunc(datetime(),datetime19.);\n`;
exports.preCodeViya = `/* if calling viya service with _job param, _program will conflict */
/* so we provide instead as __program */
%global __program _program;
%let _program=%sysfunc(coalescec(&__program,&_program));
`;
function getPreCode(serverType, macroCorePath) {
    return __awaiter(this, void 0, void 0, function* () {
        const mf_getuser = yield (0, file_1.readFile)(path_1.default.join(macroCorePath, 'base', 'mf_getuser.sas'));
        const mp_jsonout = yield (0, file_1.readFile)(path_1.default.join(macroCorePath, 'base', 'mp_jsonout.sas'));
        let content = mf_getuser + mp_jsonout;
        switch (serverType) {
            case types_1.ServerType.SasViya:
                content += yield (0, file_1.readFile)(path_1.default.join(macroCorePath, 'viya', 'mv_webout.sas'));
                content += exports.preCodeViya + (0, exports.callWeboutMacro)('mv_webout');
                break;
            case types_1.ServerType.Sas9:
                content += yield (0, file_1.readFile)(path_1.default.join(macroCorePath, 'meta', 'mm_webout.sas'));
                content += (0, exports.callWeboutMacro)('mm_webout');
                break;
            case types_1.ServerType.Sasjs:
                content += yield (0, file_1.readFile)(path_1.default.join(macroCorePath, 'server', 'ms_webout.sas'));
                content += (0, exports.callWeboutMacro)('ms_webout');
                break;
        }
        content += exports.preCodeEnd;
        return content;
    });
}
exports.getPreCode = getPreCode;
//# sourceMappingURL=getPreCode.js.map