"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAllDependencies = exports.loadDependenciesFile = void 0;
const types_1 = require("../types");
const utils_1 = require("../utils");
const _1 = require("./");
const file_1 = require("../file");
const loadDependenciesFile = ({ filePath, fileContent, configuration, target, type, programFolders, macroFolders, buildSourceFolder, macroCorePath, binaryFolders, compileTree }) => __awaiter(void 0, void 0, void 0, function* () {
    const { init, initPath, term, termPath, startUpVars, initLeaf, termLeaf } = yield (0, _1.getInitTerm)({
        configuration,
        target,
        fileType: type,
        buildSourceFolder,
        compileTree
    });
    if (type !== types_1.SASJsFileType.file) {
        fileContent = `\n* ${type} start;\n${fileContent}\n* ${type} end;`;
    }
    const fileDependencyPaths = yield (0, _1.getDependencyPaths)(`${fileContent}\n${init}\n${term}`, macroFolders, macroCorePath, compileTree);
    const initDependencyPaths = yield (0, _1.getDependencyPaths)(init, macroFolders, macroCorePath, compileTree, initLeaf);
    const termDependencyPaths = yield (0, _1.getDependencyPaths)(term, macroFolders, macroCorePath, compileTree, termLeaf);
    const allDependencyPaths = [
        ...initDependencyPaths,
        ...fileDependencyPaths,
        ...termDependencyPaths
    ];
    const initProgramDependencies = yield (0, _1.getDependencies)(initPath, init, programFolders, _1.DependencyType.Include, compileTree);
    const termProgramDependencies = yield (0, _1.getDependencies)(termPath, term, programFolders, _1.DependencyType.Include, compileTree);
    const programDependencies = yield (0, _1.getDependencies)(filePath, fileContent, programFolders, _1.DependencyType.Include, compileTree);
    const binariesDeps = yield (0, _1.getDependencies)(filePath, fileContent, binaryFolders, _1.DependencyType.Binary, compileTree);
    const dependenciesContent = yield (0, exports.getAllDependencies)(allDependencyPaths, compileTree);
    // There is no need to add any wrapping comments for file content if SASJsFileType===File
    if (type === types_1.SASJsFileType.file) {
        fileContent = [
            initProgramDependencies,
            termProgramDependencies,
            dependenciesContent,
            programDependencies,
            binariesDeps,
            fileContent
        ]
            .filter((content) => content.length)
            .join('\n');
    }
    else {
        fileContent = `* SAS Macros start;\n${initProgramDependencies}\n${termProgramDependencies}\n${dependenciesContent}\n* SAS Macros end;\n* SAS Includes start;\n${programDependencies}\n* SAS Includes end;\n* Binary Files start;\n${binariesDeps}\n* Binary Files end;\n
    ${init}${fileContent}${term}`;
        fileContent = `* ${type} Variables start;\n${startUpVars}\n* ${type} Variables end;\n${fileContent}`;
    }
    if ((type === types_1.SASJsFileType.service || type === types_1.SASJsFileType.test) &&
        target) {
        fileContent = `${yield (0, _1.getPreCode)(target.serverType, macroCorePath)}\n${fileContent}`;
    }
    return fileContent;
});
exports.loadDependenciesFile = loadDependenciesFile;
const getAllDependencies = (filePaths, compileTree) => __awaiter(void 0, void 0, void 0, function* () {
    let dependenciesContent = [];
    yield (0, utils_1.asyncForEach)([...new Set(filePaths)], (filePath) => __awaiter(void 0, void 0, void 0, function* () {
        let depFileContent = '';
        if (compileTree && Object.keys(compileTree).length) {
            depFileContent = yield compileTree.getDepContent(filePath);
        }
        else {
            depFileContent = yield (0, file_1.readFile)(filePath);
        }
        dependenciesContent.push(depFileContent);
    }));
    return dependenciesContent.join('\n');
});
exports.getAllDependencies = getAllDependencies;
//# sourceMappingURL=loadDependenciesFile.js.map