"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.validateSasjsResultsFolder = exports.validateSasjsBuildFolder = exports.validateSyncDirectories = exports.validateRepositoryName = exports.validateSyncFolder = exports.validateServerName = exports.validateContextName = exports.validateStreamConfig = exports.validateDeployConfig = exports.validateJobConfig = exports.validateTestConfig = exports.validateServiceConfig = exports.validateBuildConfig = exports.validateAuthConfigSas9 = exports.validateAuthConfig = exports.validateDocConfig = exports.validateAppLoc = exports.validateHttpsAgentOptions = exports.validateServerUrl = exports.validateTargetName = exports.validateServerType = exports.DEFAULT_SASJS_RESULTS_FOLDER = exports.DEFAULT_SASJS_BUILD_FOLDER = void 0;
const valid_url_1 = __importDefault(require("valid-url"));
const _1 = require(".");
const DEFAULT_CONTEXT_NAME = 'SAS Job Execution compute context';
const DEFAULT_SERVER_NAME = 'SASApp';
const DEFAULT_REPOSITORY_NAME = 'Foundation';
exports.DEFAULT_SASJS_BUILD_FOLDER = 'sasjsbuild';
exports.DEFAULT_SASJS_RESULTS_FOLDER = 'sasjsresults';
const validateServerType = (serverType) => {
    if (!serverType) {
        throw new Error('Invalid server type: `serverType` cannot be null or undefined.');
    }
    if (!(serverType === _1.ServerType.Sas9 ||
        serverType === _1.ServerType.SasViya ||
        serverType === _1.ServerType.Sasjs)) {
        throw new Error(`Invalid server type: Supported values for  \`serverType\` are ${_1.ServerType.SasViya}, ${_1.ServerType.Sas9} and ${_1.ServerType.Sasjs}.`);
    }
    return serverType;
};
exports.validateServerType = validateServerType;
const validateTargetName = (targetName) => {
    if (!targetName) {
        throw new Error('Invalid target name: `name` cannot be empty, null or undefined.');
    }
    if (targetName.trim().includes(' ')) {
        throw new Error('Invalid target name: `name` cannot include spaces.');
    }
    if (!/^[a-zA-Z0-9\-]+$/i.test(targetName)) {
        throw new Error('Invalid target name: `name` can only contain alphanumeric characters and dashes.');
    }
    return targetName;
};
exports.validateTargetName = validateTargetName;
const validateServerUrl = (serverUrl) => {
    if (serverUrl === null || serverUrl === undefined) {
        serverUrl = '';
    }
    if (serverUrl !== '' &&
        !valid_url_1.default.isHttpUri(serverUrl) &&
        !valid_url_1.default.isHttpsUri(serverUrl)) {
        throw new Error('Invalid server URL: `serverUrl` should either be an empty string or a valid URL of the form http(s)://your-server.com(:port).');
    }
    return serverUrl;
};
exports.validateServerUrl = validateServerUrl;
const validateHttpsAgentOptions = (httpsAgentOptions) => {
    if (!httpsAgentOptions)
        return;
    if (typeof httpsAgentOptions !== 'object') {
        throw new Error('Invalid value: `httpsAgentOptions` should either be an empty or an object of `HttpsAgentOptions`');
    }
    if (httpsAgentOptions.allowInsecureRequests === null ||
        httpsAgentOptions.allowInsecureRequests === undefined) {
        httpsAgentOptions.allowInsecureRequests = false;
    }
    else if (typeof httpsAgentOptions.allowInsecureRequests !== 'boolean') {
        throw new Error('Invalid value: `httpsAgentOptions.allowInsecureRequests` should either be an empty or a boolean');
    }
    if (typeof httpsAgentOptions.caPath !== 'string') {
        httpsAgentOptions.caPath = undefined;
    }
    if (typeof httpsAgentOptions.keyPath !== 'string') {
        httpsAgentOptions.keyPath = undefined;
    }
    if (typeof httpsAgentOptions.certPath !== 'string') {
        httpsAgentOptions.certPath = undefined;
    }
    return httpsAgentOptions;
};
exports.validateHttpsAgentOptions = validateHttpsAgentOptions;
const validateAppLoc = (appLoc) => {
    if (!appLoc) {
        throw new Error('Invalid app location: `appLoc` cannot be empty, null or undefined.');
    }
    if (!appLoc.startsWith('/')) {
        throw new Error('Invalid app location: `appLoc` must start with a `/`.');
    }
    return appLoc;
};
exports.validateAppLoc = validateAppLoc;
const validateDocConfig = (docConfig) => {
    if (!docConfig) {
        docConfig = {};
    }
    if (typeof docConfig.displayMacroCore !== 'boolean') {
        docConfig.displayMacroCore = undefined;
    }
    if (typeof docConfig.enableLineage !== 'boolean') {
        docConfig.enableLineage = undefined;
    }
    if (typeof docConfig.outDirectory !== 'string') {
        docConfig.outDirectory = undefined;
    }
    if (typeof docConfig.dataControllerUrl === 'string') {
        if (docConfig.dataControllerUrl !== '' &&
            !valid_url_1.default.isHttpUri(docConfig.dataControllerUrl) &&
            !valid_url_1.default.isHttpsUri(docConfig.dataControllerUrl)) {
            throw new Error('Invalid Data Controller Url: `dataControllerUrl` should either be an empty string or a valid URL of the form http(s)://your-server.com(:port).');
        }
    }
    else {
        docConfig.dataControllerUrl = undefined;
    }
    return docConfig;
};
exports.validateDocConfig = validateDocConfig;
const validateAuthConfig = (authConfig) => {
    if (!authConfig) {
        throw new Error('Invalid auth config: JSON cannot be null or undefined.');
    }
    return authConfig;
};
exports.validateAuthConfig = validateAuthConfig;
const validateAuthConfigSas9 = (authConfigSas9) => {
    if (!authConfigSas9) {
        throw new Error('Invalid auth config for sas9: JSON cannot be null or undefined.');
    }
    if (!authConfigSas9.userName || !authConfigSas9.password) {
        throw new Error('Invalid auth config for sas9: userName and password can not be empty');
    }
    return authConfigSas9;
};
exports.validateAuthConfigSas9 = validateAuthConfigSas9;
const validateBuildConfig = (buildConfig, defaultName) => {
    if (!buildConfig) {
        throw new Error('Invalid build config: JSON cannot be null or undefined.');
    }
    if (!buildConfig.buildOutputFileName) {
        buildConfig.buildOutputFileName = `${defaultName}.sas`;
    }
    if (!buildConfig.initProgram) {
        buildConfig.initProgram = '';
    }
    if (!buildConfig.termProgram) {
        buildConfig.termProgram = '';
    }
    if (!buildConfig.macroVars) {
        buildConfig.macroVars = {};
    }
    return buildConfig;
};
exports.validateBuildConfig = validateBuildConfig;
const validateServiceConfig = (serviceConfig) => {
    if (!serviceConfig) {
        throw new Error('Invalid service config: JSON cannot be null or undefined.');
    }
    if (!serviceConfig.initProgram) {
        serviceConfig.initProgram = '';
    }
    if (!serviceConfig.termProgram) {
        serviceConfig.termProgram = '';
    }
    if (!serviceConfig.serviceFolders) {
        serviceConfig.serviceFolders = [];
    }
    if (!serviceConfig.macroVars) {
        serviceConfig.macroVars = {};
    }
    return serviceConfig;
};
exports.validateServiceConfig = validateServiceConfig;
const validateTestConfig = (testConfig) => {
    if (!testConfig) {
        throw new Error('Invalid test config: JSON cannot be null or undefined.');
    }
    if (!testConfig.initProgram)
        testConfig.initProgram = '';
    if (!testConfig.termProgram)
        testConfig.termProgram = '';
    if (!testConfig.macroVars)
        testConfig.macroVars = {};
    if (!testConfig.testSetUp)
        testConfig.testSetUp = '';
    if (!testConfig.testTearDown)
        testConfig.testTearDown = '';
    return testConfig;
};
exports.validateTestConfig = validateTestConfig;
const validateJobConfig = (jobConfig) => {
    if (!jobConfig) {
        throw new Error('Invalid job config: JSON cannot be null or undefined.');
    }
    if (!jobConfig.initProgram) {
        jobConfig.initProgram = '';
    }
    if (!jobConfig.termProgram) {
        jobConfig.termProgram = '';
    }
    if (!jobConfig.jobFolders) {
        jobConfig.jobFolders = [];
    }
    if (!jobConfig.macroVars) {
        jobConfig.macroVars = {};
    }
    return jobConfig;
};
exports.validateJobConfig = validateJobConfig;
const validateDeployConfig = (deployConfig) => {
    if (!deployConfig) {
        throw new Error('Invalid deploy config: JSON cannot be null or undefined.');
    }
    deployConfig.deployServicePack = !!deployConfig.deployServicePack;
    if (!deployConfig.deployScripts) {
        deployConfig.deployScripts = [];
    }
    return deployConfig;
};
exports.validateDeployConfig = validateDeployConfig;
const validateStreamConfig = (streamConfig) => {
    if (!streamConfig) {
        throw new Error('Invalid stream config: JSON cannot be null or undefined.');
    }
    if (streamConfig.streamWeb !== true && streamConfig.streamWeb !== false) {
        throw new Error('Invalid stream config: `streamWeb` cannot be a non-boolean value.');
    }
    if (streamConfig.streamWeb && !streamConfig.streamWebFolder) {
        throw new Error('Invalid stream config: `streamWebFolder` cannot be empty, null or undefined when `streamWeb` is true.');
    }
    if (streamConfig.streamWeb && !streamConfig.webSourcePath) {
        throw new Error('Invalid stream config: `webSourcePath` should contain the path to your frontend application eg build, dist, or src.');
    }
    if (streamConfig.streamLogo && typeof streamConfig.streamLogo !== 'string') {
        streamConfig.streamLogo = undefined;
    }
    if (!streamConfig.assetPaths) {
        streamConfig.assetPaths = [];
    }
    if (!streamConfig.streamServiceName) {
        streamConfig.streamServiceName = 'clickme';
    }
    return streamConfig;
};
exports.validateStreamConfig = validateStreamConfig;
const validateContextName = (contextName, serverType) => {
    if (serverType === _1.ServerType.SasViya && !contextName) {
        return DEFAULT_CONTEXT_NAME;
    }
    return contextName;
};
exports.validateContextName = validateContextName;
const validateServerName = (serverName, serverType) => {
    if (serverType === _1.ServerType.Sas9 && !serverName) {
        return DEFAULT_SERVER_NAME;
    }
    return serverName;
};
exports.validateServerName = validateServerName;
const validateSyncFolder = (syncFolder) => {
    if (typeof syncFolder !== 'string') {
        return;
    }
    if (!syncFolder)
        return;
    return syncFolder;
};
exports.validateSyncFolder = validateSyncFolder;
const validateRepositoryName = (repositoryName, serverType) => {
    if (serverType === _1.ServerType.Sas9 && !repositoryName) {
        return DEFAULT_REPOSITORY_NAME;
    }
    return repositoryName;
};
exports.validateRepositoryName = validateRepositoryName;
const validateSyncDirectories = (syncDirectories) => {
    if (!syncDirectories) {
        throw new Error('Invalid syncDirectories config: JSON cannot be null or undefined.');
    }
    syncDirectories.forEach((obj) => {
        if (!obj.local || !obj.remote)
            throw new Error(`Invalid syncDirectory config: values of property 'local' and 'remote can not be empty or undefined`);
    });
    return syncDirectories;
};
exports.validateSyncDirectories = validateSyncDirectories;
const validateSasjsBuildFolder = (folderName) => {
    if (typeof folderName !== 'string') {
        throw new Error(`Invalid type of value (${typeof folderName}) is provided for property 'sasjsBuildFolder' in config. Required is string.`);
    }
    if (!folderName)
        return exports.DEFAULT_SASJS_BUILD_FOLDER;
    return folderName;
};
exports.validateSasjsBuildFolder = validateSasjsBuildFolder;
const validateSasjsResultsFolder = (folderName) => {
    if (typeof folderName !== 'string') {
        throw new Error(`Invalid type of value (${typeof folderName}) is provided for property 'sasjsResultsFolder' in config. Required is string.`);
    }
    if (!folderName)
        return exports.DEFAULT_SASJS_RESULTS_FOLDER;
    return folderName;
};
exports.validateSasjsResultsFolder = validateSasjsResultsFolder;
//# sourceMappingURL=targetValidators.js.map